Class: RailsErrorDashboard::DigestMailer

Inherits:
ApplicationMailer show all
Defined in:
app/mailers/rails_error_dashboard/digest_mailer.rb

Instance Method Summary collapse

Instance Method Details

#digest_summary(digest, recipients, locale: I18nStore::DEFAULT_LOCALE) ⇒ Object

Parameters:

  • locale (String) (defaults to: I18nStore::DEFAULT_LOCALE)

    resolved at enqueue time, never read from Current — a mailer renders outside the request that set it.



7
8
9
10
11
12
13
14
15
16
# File 'app/mailers/rails_error_dashboard/digest_mailer.rb', line 7

def digest_summary(digest, recipients, locale: I18nStore::DEFAULT_LOCALE)
  @digest = digest
  @dashboard_url = dashboard_base_url
  @red_locale = locale

  mail(
    to: recipients,
    subject: subject_for(digest, locale)
  )
end